==> openshift-model-6.4.1-sources.jar: io/fabric8/openshift/api/model/DockerBuildStrategyFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.util.Iterator;
import io.fabric8.kubernetes.api.model.EnvVar;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface DockerBuildStrategyFluent<A extends DockerBuildStrategyFluent<A>> extends Fluent<A>{
  public A addToBuildArgs(Integer index,EnvVar item);
  public A setToBuildArgs(Integer index,EnvVar item);
  public A addToBuildArgs(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A addAllToBuildArgs(Collection<EnvVar> items);
  public A removeFromBuildArgs(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A removeAllFromBuildArgs(Collection<EnvVar> items);
  public List<EnvVar> getBuildArgs();
  public EnvVar getBuildArg(Integer index);
  public EnvVar getFirstBuildArg();
  public EnvVar getLastBuildArg();
  public EnvVar getMatchingBuildArg(Predicate<EnvVar> predicate);
  public Boolean hasMatchingBuildArg(Predicate<EnvVar> predicate);
  public A withBuildArgs(List<EnvVar> buildArgs);
  public A withBuildArgs(io.fabric8.kubernetes.api.model.EnvVar... buildArgs);
  public Boolean hasBuildArgs();
  public String getDockerfilePath();
  public A withDockerfilePath(String dockerfilePath);
  public Boolean hasDockerfilePath();
  public A addToEnv(Integer index,EnvVar item);
  public A setToEnv(Integer index,EnvVar item);
  public A addToEnv(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A addAllToEnv(Collection<EnvVar> items);
  public A removeFromEnv(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A removeAllFromEnv(Collection<EnvVar> items);
  public List<EnvVar> getEnv();
  public EnvVar getEnv(Integer index);
  public EnvVar getFirstEnv();
  public EnvVar getLastEnv();
  public EnvVar getMatchingEnv(Predicate<EnvVar> predicate);
  public Boolean hasMatchingEnv(Predicate<EnvVar> predicate);
  public A withEnv(List<EnvVar> env);
  public A withEnv(io.fabric8.kubernetes.api.model.EnvVar... env);
  public Boolean hasEnv();
  public Boolean getForcePull();
  public A withForcePull(Boolean forcePull);
  public Boolean hasForcePull();
  
  /**
   * This method has been deprecated, please use method buildFrom instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getFrom();
  public ObjectReference buildFrom();
  public A withFrom(ObjectReference from);
  public Boolean hasFrom();
  public DockerBuildStrategyFluent.FromNested<A> withNewFrom();
  public DockerBuildStrategyFluent.FromNested<A> withNewFromLike(ObjectReference item);
  public DockerBuildStrategyFluent.FromNested<A> editFrom();
  public DockerBuildStrategyFluent.FromNested<A> editOrNewFrom();
  public DockerBuildStrategyFluent.FromNested<A> editOrNewFromLike(ObjectReference item);
  public String getImageOptimizationPolicy();
  public A withImageOptimizationPolicy(String imageOptimizationPolicy);
  public Boolean hasImageOptimizationPolicy();
  public Boolean getNoCache();
  public A withNoCache(Boolean noCache);
  public Boolean hasNoCache();
  
  /**
   * This method has been deprecated, please use method buildPullSecret instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getPullSecret();
  public LocalObjectReference buildPullSecret();
  public A withPullSecret(LocalObjectReference pullSecret);
  public Boolean hasPullSecret();
  public A withNewPullSecret(String name);
  public DockerBuildStrategyFluent.PullSecretNested<A> withNewPullSecret();
  public DockerBuildStrategyFluent.PullSecretNested<A> withNewPullSecretLike(LocalObjectReference item);
  public DockerBuildStrategyFluent.PullSecretNested<A> editPullSecret();
  public DockerBuildStrategyFluent.PullSecretNested<A> editOrNewPullSecret();
  public DockerBuildStrategyFluent.PullSecretNested<A> editOrNewPullSecretLike(LocalObjectReference item);
  public A addToVolumes(Integer index,BuildVolume item);
  public A setToVolumes(Integer index,BuildVolume item);
  public A addToVolumes(io.fabric8.openshift.api.model.BuildVolume... items);
  public A addAllToVolumes(Collection<BuildVolume> items);
  public A removeFromVolumes(io.fabric8.openshift.api.model.BuildVolume... items);
  public A removeAllFromVolumes(Collection<BuildVolume> items);
  public A removeMatchingFromVolumes(Predicate<BuildVolumeBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildVolumes instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<BuildVolume> getVolumes();
  public List<BuildVolume> buildVolumes();
  public BuildVolume buildVolume(Integer index);
  public BuildVolume buildFirstVolume();
  public BuildVolume buildLastVolume();
  public BuildVolume buildMatchingVolume(Predicate<BuildVolumeBuilder> predicate);
  public Boolean hasMatchingVolume(Predicate<BuildVolumeBuilder> predicate);
  public A withVolumes(List<BuildVolume> volumes);
  public A withVolumes(io.fabric8.openshift.api.model.BuildVolume... volumes);
  public Boolean hasVolumes();
  public DockerBuildStrategyFluent.VolumesNested<A> addNewVolume();
  public DockerBuildStrategyFluent.VolumesNested<A> addNewVolumeLike(BuildVolume item);
  public DockerBuildStrategyFluent.VolumesNested<A> setNewVolumeLike(Integer index,BuildVolume item);
  public DockerBuildStrategyFluent.VolumesNested<A> editVolume(Integer index);
  public DockerBuildStrategyFluent.VolumesNested<A> editFirstVolume();
  public DockerBuildStrategyFluent.VolumesNested<A> editLastVolume();
  public DockerBuildStrategyFluent.VolumesNested<A> editMatchingVolume(Predicate<BuildVolumeBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withForcePull();
  public A withNoCache();
  public interface FromNested<N> extends Nested<N>,ObjectReferenceFluent<DockerBuildStrategyFluent.FromNested<N>>{
    public N and();
    public N endFrom();
    
  }
  public interface PullSecretNested<N> extends Nested<N>,LocalObjectReferenceFluent<DockerBuildStrategyFluent.PullSecretNested<N>>{
    public N and();
    public N endPullSecret();
    
  }
  public interface VolumesNested<N> extends Nested<N>,BuildVolumeFluent<DockerBuildStrategyFluent.VolumesNested<N>>{
    public N and();
    public N endVolume();
    
  }
  
}

==> openshift-model-6.7.0-sources.jar: io/fabric8/openshift/api/model/DockerBuildStrategyFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.util.Iterator;
import io.fabric8.kubernetes.api.model.EnvVar;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface DockerBuildStrategyFluent<A extends DockerBuildStrategyFluent<A>> extends Fluent<A>{
  public A addToBuildArgs(int index,EnvVar item);
  public A setToBuildArgs(int index,EnvVar item);
  public A addToBuildArgs(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A addAllToBuildArgs(Collection<EnvVar> items);
  public A removeFromBuildArgs(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A removeAllFromBuildArgs(Collection<EnvVar> items);
  public List<EnvVar> getBuildArgs();
  public EnvVar getBuildArg(int index);
  public EnvVar getFirstBuildArg();
  public EnvVar getLastBuildArg();
  public EnvVar getMatchingBuildArg(Predicate<EnvVar> predicate);
  public Boolean hasMatchingBuildArg(Predicate<EnvVar> predicate);
  public A withBuildArgs(List<EnvVar> buildArgs);
  public A withBuildArgs(io.fabric8.kubernetes.api.model.EnvVar... buildArgs);
  public Boolean hasBuildArgs();
  public String getDockerfilePath();
  public A withDockerfilePath(String dockerfilePath);
  public Boolean hasDockerfilePath();
  public A addToEnv(int index,EnvVar item);
  public A setToEnv(int index,EnvVar item);
  public A addToEnv(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A addAllToEnv(Collection<EnvVar> items);
  public A removeFromEnv(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A removeAllFromEnv(Collection<EnvVar> items);
  public List<EnvVar> getEnv();
  public EnvVar getEnv(int index);
  public EnvVar getFirstEnv();
  public EnvVar getLastEnv();
  public EnvVar getMatchingEnv(Predicate<EnvVar> predicate);
  public Boolean hasMatchingEnv(Predicate<EnvVar> predicate);
  public A withEnv(List<EnvVar> env);
  public A withEnv(io.fabric8.kubernetes.api.model.EnvVar... env);
  public Boolean hasEnv();
  public Boolean getForcePull();
  public A withForcePull(Boolean forcePull);
  public Boolean hasForcePull();
  
  /**
   * This method has been deprecated, please use method buildFrom instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getFrom();
  public ObjectReference buildFrom();
  public A withFrom(ObjectReference from);
  public Boolean hasFrom();
  public DockerBuildStrategyFluent.FromNested<A> withNewFrom();
  public DockerBuildStrategyFluent.FromNested<A> withNewFromLike(ObjectReference item);
  public DockerBuildStrategyFluent.FromNested<A> editFrom();
  public DockerBuildStrategyFluent.FromNested<A> editOrNewFrom();
  public DockerBuildStrategyFluent.FromNested<A> editOrNewFromLike(ObjectReference item);
  public String getImageOptimizationPolicy();
  public A withImageOptimizationPolicy(String imageOptimizationPolicy);
  public Boolean hasImageOptimizationPolicy();
  public Boolean getNoCache();
  public A withNoCache(Boolean noCache);
  public Boolean hasNoCache();
  
  /**
   * This method has been deprecated, please use method buildPullSecret instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getPullSecret();
  public LocalObjectReference buildPullSecret();
  public A withPullSecret(LocalObjectReference pullSecret);
  public Boolean hasPullSecret();
  public A withNewPullSecret(String name);
  public DockerBuildStrategyFluent.PullSecretNested<A> withNewPullSecret();
  public DockerBuildStrategyFluent.PullSecretNested<A> withNewPullSecretLike(LocalObjectReference item);
  public DockerBuildStrategyFluent.PullSecretNested<A> editPullSecret();
  public DockerBuildStrategyFluent.PullSecretNested<A> editOrNewPullSecret();
  public DockerBuildStrategyFluent.PullSecretNested<A> editOrNewPullSecretLike(LocalObjectReference item);
  public A addToVolumes(int index,BuildVolume item);
  public A setToVolumes(int index,BuildVolume item);
  public A addToVolumes(io.fabric8.openshift.api.model.BuildVolume... items);
  public A addAllToVolumes(Collection<BuildVolume> items);
  public A removeFromVolumes(io.fabric8.openshift.api.model.BuildVolume... items);
  public A removeAllFromVolumes(Collection<BuildVolume> items);
  public A removeMatchingFromVolumes(Predicate<BuildVolumeBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildVolumes instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<BuildVolume> getVolumes();
  public List<BuildVolume> buildVolumes();
  public BuildVolume buildVolume(int index);
  public BuildVolume buildFirstVolume();
  public BuildVolume buildLastVolume();
  public BuildVolume buildMatchingVolume(Predicate<BuildVolumeBuilder> predicate);
  public Boolean hasMatchingVolume(Predicate<BuildVolumeBuilder> predicate);
  public A withVolumes(List<BuildVolume> volumes);
  public A withVolumes(io.fabric8.openshift.api.model.BuildVolume... volumes);
  public Boolean hasVolumes();
  public DockerBuildStrategyFluent.VolumesNested<A> addNewVolume();
  public DockerBuildStrategyFluent.VolumesNested<A> addNewVolumeLike(BuildVolume item);
  public DockerBuildStrategyFluent.VolumesNested<A> setNewVolumeLike(int index,BuildVolume item);
  public DockerBuildStrategyFluent.VolumesNested<A> editVolume(int index);
  public DockerBuildStrategyFluent.VolumesNested<A> editFirstVolume();
  public DockerBuildStrategyFluent.VolumesNested<A> editLastVolume();
  public DockerBuildStrategyFluent.VolumesNested<A> editMatchingVolume(Predicate<BuildVolumeBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withForcePull();
  public A withNoCache();
  public interface FromNested<N> extends Nested<N>,ObjectReferenceFluent<DockerBuildStrategyFluent.FromNested<N>>{
    public N and();
    public N endFrom();
    
  }
  public interface PullSecretNested<N> extends Nested<N>,LocalObjectReferenceFluent<DockerBuildStrategyFluent.PullSecretNested<N>>{
    public N and();
    public N endPullSecret();
    
  }
  public interface VolumesNested<N> extends Nested<N>,BuildVolumeFluent<DockerBuildStrategyFluent.VolumesNested<N>>{
    public N and();
    public N endVolume();
    
  }
  
}
